================
Django Ratelimit
================

Django Ratelimit provides a decorator to rate-limit views. Limiting can
be based on IP address or a field in the request--either a GET or POST
variable.

.. image:: https://github.com/jsocol/django-ratelimit/workflows/test/badge.svg?branch=main
   :target: https://github.com/jsocol/django-ratelimit/actions

:Code:          https://github.com/jsocol/django-ratelimit
:License:       Apache Software License 2.0; see LICENSE file
:Issues:        https://github.com/jsocol/django-ratelimit/issues
:Documentation: http://django-ratelimit.readthedocs.io/
